==> data_api-7.x-1.0-rc9.tar.gz: data_api/tests/Drupal/data_api/DataMock.php <==
<?php
namespace Drupal\data_api;

// Globals will pull in mocked classes, exceptions, etc.
require_once dirname(__FILE__) . '/../../globals.php';

class DataMock extends Data
{
    protected function entity_extract_ids($entity_type, $entity)
    {
        $type = null;
        if ($entity_type === 'user') {
            $type = 'user';
        }
        elseif (isset($entity->type)) {
            $type = $entity->type;
        }
        else {
            throw new \EntityMalformedException("Missing bundle property on entity of type $entity_type.");
        }

        return array(null, null, $type);
    }

    protected function field_get_items($entity_type, $entity, $field_name, $langcode = null
    ) {
        global $language;
        $default = empty($language) ? 'und' : $language;
        $langcode = is_null($langcode) ? $default : $langcode;

        return $entity->{$field_name}[$langcode];
    }

    protected function field_info_instances($entity_type = null, $bundle_name = null
    ) {
        global $entity;
        $temp = (array) clone $entity;
        $fields = array();
        foreach (array_keys($temp) as $property) {
            if (strpos($property, 'field_') === 0) {
                $fields[] = $property;
            }
        }

        return array_fill_keys($fields, array());
    }

    protected function field_language($entity_type, $entity, $field_name = null, $langcode = null
    ) {
        global $language;

        return empty($language) ? 'und' : $language;
    }
}

==> data_api-7.x-1.1-rc2.tar.gz: data_api/tests/Drupal/data_api/DataMock.php <==
<?php
namespace Drupal\data_api;

// Globals will pull in mocked classes, exceptions, etc.
require_once dirname(__FILE__) . '/../../globals.php';

class DataMock extends Data
{

    protected function entity_extract_ids($entity_type, $entity)
    {
        $type = null;
        if ($entity_type === 'user') {
            $type = 'user';
        }
        elseif (isset($entity->type)) {
            $type = $entity->type;
        }
        else {
            throw new \EntityMalformedException("Missing bundle property on entity of type $entity_type.");
        }

        return array(null, null, $type);
    }

    protected function field_get_items($entity_type, $entity, $field_name, $langcode = null
    ) {
        global $language;
        $default = empty($language) ? 'und' : $language;
        $langcode = is_null($langcode) ? $default : $langcode;

        if (!isset($entity->{$field_name}[$langcode])) {
            $entity->{$field_name}[$langcode] = array();
        }

        return $entity->{$field_name}[$langcode];
    }

    protected function field_info_instances($entity_type = null, $bundle_name = null
    ) {
        global $entity;
        $info = array();
        if (is_object($entity)) {
            $temp = (array) clone $entity;
            $fields = array();
            foreach (array_keys($temp) as $property) {
                if (strpos($property, 'field_') === 0) {
                    $fields[] = $property;
                }
            }

            $info = array_fill_keys($fields, array());
        }

        return $info;
    }

    protected function field_language($entity_type, $entity, $field_name = null, $langcode = null
    ) {
        global $language;

        return empty($language) ? 'und' : $language;
    }
}
